<template>
  <div class="waste-gas-day-chart-box echarts-box">
    <div class="tab-scroll">
      <PublicDataStandard :dataStandard="dataStandard"></PublicDataStandard>
    </div>
    <div class="echarts-form">
      <span class="demonstration">开始时间：</span>
      <el-date-picker v-model="formData.timeStart" value-format="yyyy-MM-dd HH:mm:ss" type="datetime" size="mini"></el-date-picker>
      <span class="demonstration">结束时间：</span>
      <el-date-picker v-model="formData.timeEnd" value-format="yyyy-MM-dd HH:mm:ss" type="datetime" size="mini"></el-date-picker>
      <span class="demonstration">采样点数：</span>
      <el-select class="selectBox" v-model="formData.region" placeholder="请选择" size="mini">
        <el-option v-for="(item,index) in formData.regionList" :key="index" :label="item" :value="item"></el-option>
      </el-select>
      <el-button @click="querySearch">查询</el-button>
      <el-popover
          placement="top"
          width="100%"
          popper-class="popoverBoxStyle"
          trigger="click">
        <dynamic-table :tableData="tableData" :tableHeader="tableConfig" v-if="tableData"></dynamic-table>
        <el-button class="mingxiBtn" slot="reference" id="mingxiBtn">明细表</el-button>
      </el-popover>
    </div>
    <div class="echarts-chart">
      <div ref="wastegasday"></div>
    </div>
    <span class="time-select">{{ formData.timeStart }}日—{{ formData.timeEnd }}日</span>
  </div>
</template>

<script>

import PublicDataStandard from '../PublicDataStandard'
import 'dayjs/locale/es'
import dayjs from 'dayjs'
import mapApi from '@/api/mapApi'
import DynamicTable from '../../../views/popup/DynamicHeader/DynamicTable' // 多级表头表格

export default {
  name: 'DayData',
  components: {
    PublicDataStandard,
    DynamicTable
  },
  props: {
    OnlineMonEmissPointId: {
      type: Number
    }
  },
  data () {
    return {
      // tab栏传递接收数据
      dataStandard: [],
      tableData: [],
      formData: {
        region: '25',
        regionList: [25, 50, 75, 100],
        timeStart: dayjs().subtract(1, 'month').format('YYYY-MM-DD'),
        timeEnd: dayjs().format('YYYY-MM-DD')
      },
      dataType: 1,
      myChart: null,
      exhbzz: null,
      jcdID: 1,
      exhbzzList: [],
      bzz: null,
      bzzList: [],
      // 配置明细表表头
      tableConfig: [
        {
          id: 100,
          label: '排放点',
          prop: 'OnLineMonEmissPointName'
        },
        {
          id: 200,
          label: '监测时间',
          prop: 'MonTimeStr'
        },
        {
          id: 300,
          label: '氮氧化物',
          prop: 'PoltmtrlName',
          children: [
            {
              id: 310,
              label: '浓度（mg/m³）',
              prop: '氮氧化物_OrglQty'
            },
            {
              id: 320,
              label: '折算值（mg/m³））',
              prop: '氮氧化物_ConvertQty'
            },
            {
              id: 330,
              label: '标准值（mg/m³）',
              prop: '氮氧化物_StdValue'
            },
            {
              id: 340,
              label: '排放量（kg/h）',
              prop: '氮氧化物_EmissQty'
            }
          ]
        },
        {
          id: 400,
          label: '二氧化硫',
          prop: 'PoltmtrlName',
          children: [
            {
              id: 410,
              label: '浓度（mg/m³）',
              prop: '氮氧化物_OrglQty'
            },
            {
              id: 420,
              label: '折算值（mg/m³））',
              prop: '氮氧化物_ConvertQty'
            },
            {
              id: 430,
              label: '标准值（mg/m³）',
              prop: '氮氧化物_StdValue'
            },
            {
              id: 440,
              label: '排放量（kg/h）',
              prop: '氮氧化物_EmissQty'
            }
          ]
        },
        {
          id: 500,
          label: '烟尘',
          prop: 'PoltmtrlName',
          children: [
            {
              id: 510,
              label: '浓度（mg/m³）',
              prop: '氮氧化物_OrglQty'
            },
            {
              id: 520,
              label: '折算值（mg/m³））',
              prop: '氮氧化物_ConvertQty'
            },
            {
              id: 530,
              label: '标准值（mg/m³）',
              prop: '氮氧化物_StdValue'
            },
            {
              id: 540,
              label: '排放量（kg/h）',
              prop: '氮氧化物_EmissQty'
            }
          ]
        },
        {
          id: 600,
          label: '废气流量',
          prop: '',
          children: [
            {
              id: 610,
              label: '气量（m³/h）',
              prop: '废气流量_MonQty'
            }
          ]
        }
      ]
    }
  },
  mounted () {
    this.$nextTick(() => {
      if (!this.OnlineMonEmissPointId) {
        document.querySelector('.waste-gas-day-chart-box').innerHTML = '没有查询到数据！'
        document.querySelector('.waste-gas-day-chart-box').style.textAlign = 'center'
        document.querySelector('.waste-gas-day-chart-box').style.height = '2.02rem'
        document.querySelector('.waste-gas-day-chart-box').style.lineHeight = '1rem'
      } else {
        this.initnData()
      }
    })
  },
  methods: {
    querySearch () {
      this.initnData()
    },
    async initnData () {
      const data = {
        poltSourceId: '',
        poltMtrlId: '',
        emissTypeId: '',
        onLineMonEmissPointId: this.OnlineMonEmissPointId,
        monItemId: '28,31,226',
        beginTime: this.formData.timeStart,
        endTime: this.formData.timeEnd,
        dataType: this.dataType
      }
      const result = (await mapApi.getWasteGasMonData(data)).Result.DataInfo
      // console.log(result)
      this.get24HourDate(result)
    },
    get24HourDate (res) {
      if (res.length > 0) {
        this.dataStandard = []
        this.tableData = this.analysisResult(res) // 小时明细表解析结果
        // 处理数据开始
        const d = res
        const nameList = [] // 存放图例
        const dateList = [] // 存放时间
        const dataList = [] // 存放数据
        let data
        const bzh = []

        // wrwIDS = []

        for (let i = 0; i < d.length; i++) {
          if (d[i].MonItemId === '29') {
            continue
          }
          // 20190430 add  获取监测点id 污染物id  检测项id
          // getWRW(d[i])
          const MonTimeStr = d[i].MonTimeStr

          const d1 = MonTimeStr.split('/')
          // var d2=d1[2].split(' ');
          let strDate
          if (d1[1] > 9) {
            // if(d2[0]>9){
            strDate = MonTimeStr.substring(8, 10) + '日'
            // }else {
            //     strDate=MonTimeStr.substring(8,9)+"日";
            // }
          } else {
            // if(d2[0]>9){
            strDate = MonTimeStr.substring(7, 9) + '日'
            // }else {
            //     strDate=MonTimeStr.substring(7,8)+"日";
            // }
          }

          if (nameList.length === 0) {
            nameList.push(d[i].PoltmtrlName.trim())
            this.dataStandard.push({
              current: {
                name: d[i].PoltmtrlName.trim(),
                val: ''
              },
              standard: {
                name: '标准',
                val: ''
              }
            })
            dateList.push(strDate)

            bzh.push(d[i].StdValue)
            data = {
              name: d[i].PoltmtrlName.trim(),
              data: []
            }
            if (d[i].MonQty !== null) {
              data.data.push(d[i].MonQty)
            }
            dataList.push(data)
          } else if (nameList.indexOf(d[i].PoltmtrlName.trim()) < 0) {
            nameList.push(d[i].PoltmtrlName)
            this.dataStandard.push({
              current: {
                name: d[i].PoltmtrlName.trim(),
                val: ''
              },
              standard: {
                name: '标准',
                val: ''
              }
            })
            bzh.push(d[i].StdValue)
            data = {
              name: d[i].PoltmtrlName.trim(),
              data: []
            }
            if (d[i].MonQty !== null) {
              data.data.push(d[i].MonQty)
            }
            dataList.push(data)
          } else {
            if (dateList.indexOf(strDate) < 0) {
              dateList.push(strDate)
            }
            for (var j = 0; j < dataList.length; j++) {
              if (d[i].PoltmtrlName.trim() === dataList[j].name) {
                dataList[j].data.push(d[i].MonQty)
              }
            }
          }
        }
        // 处理数据结束

        var divid = 'mychart1eff'

        var title = name

        var lengList = []
        var objTemp

        for (var l = 0; l < nameList.length; l++) {
          var obj
          var iconurl
          if (nameList[l] === '二氧化硫') {
            iconurl = 'image://../assets/imgs/legend/SO2.png'
          } else if (nameList[l] === '氮氧化物') {
            iconurl = 'image://../assets/imgs/legend/NOX.png'
          } else if (nameList[l] === '烟尘') {
            iconurl = 'image://../assets/imgs/legend/YanChen.png'
          } else if (nameList[l] === '非甲烷总烃') {
            iconurl = 'image://../assets/imgs/legend/grn.png'
          } else if (nameList[l] === '温度') {
            iconurl = 'image://../assets/imgs/legend/WenDu.png'
          } else {
            iconurl = 'image://../assets/imgs/legend/VOCs.png'
          }

          if (nameList[l] === '废水' || nameList[l] === '废水流量') { // 将废水流量排到数组最后
            objTemp = {
              name: nameList[l],
              icon: iconurl,
              textStyle: {
                color: '#ccc'
              },
              itemWidth: 20,
              itemHeight: 5
            }
          } else {
            obj = {
              name: nameList[l],
              icon: iconurl,
              textStyle: {
                color: '#ccc'
              },
              itemWidth: 20,
              itemHeight: 5
            }
            lengList.push(obj)
          }

          this.bzz = {
            name: nameList[l],
            bzhui: bzh[l]
          }
          this.bzzList.push(this.bzz)
        }
        lengList.push(objTemp)

        const legend = lengList
        const xdata = dateList.reverse()
        const ydatas = []

        for (let j = 0; j < nameList.length; j++) {
          var zdcbcolor, zxcolor
          if (nameList[j] === '二氧化硫') {
            zdcbcolor = 'red'
            zxcolor = '#fff21c'
          } else if (nameList[j] === '氮氧化物') {
            zdcbcolor = 'red'
            zxcolor = '#00B0F0'
          } else if (nameList[j] === '总磷') {
            zdcbcolor = 'red'
            zxcolor = '#f48183'
          } else if (nameList[j] === '废气流量') {
            zdcbcolor = 'red'
            zxcolor = '#70ff49'
          } else {
            zdcbcolor = 'red'
            zxcolor = '#d9f2f4'
          }

          let sdata = []

          for (let k = 0; k < dataList.length; k++) {
            if (nameList[j].trim() === dataList[k].name.trim()) {
              sdata = dataList[k].data.reverse()
            }
          }

          const ydata = {
            name: nameList[j],
            data: sdata,
            zdcbcolor: zdcbcolor,
            zxcolor: zxcolor,
            bzz: bzh[j]
          }
          ydatas.push(ydata)
        }

        const yname = '浓度(mg/l)'
        for (var t = 0; t < this.dataStandard.length; t++) {
          this.dataStandard[t].current.val = ydatas[t].data[ydatas[t].data.length - 1].toFixed(2)
          this.dataStandard[t].standard.val = ydatas[t].bzz
        }
        this.CreateChart(divid, title, legend, xdata, ydatas, yname, this.jcdID, this.datatype)
      }
    },
    CreateChart (id, title, legend, xdata, ydatas, yname, jcdID, datatype) {
      this.myChart = this.$echarts.init(this.$refs.wastegasday)
      this.myChart.clear()
      let dataUnit = ''
      if (datatype === 1) {
        dataUnit = '气量(m³/d)'
      } else {
        dataUnit = '气量(m³/h)'
      }

      const serLists = []
      for (let j = 0; j < ydatas.length; j++) {
        const len = ydatas[j].data.length
        for (let k = 0; k < len; k++) {
          const it = ydatas[j].data[k]
          const it2 = parseFloat(it).toFixed(2)
          ydatas[j].data[k] = it2
        }
      }

      const bzzList = this.bzzList

      for (let i = 0; i < ydatas.length; i++) {
        const zdcbcolor = ydatas[i].zdcbcolor
        const bzz = ydatas[i].bzz
        let obj
        if (bzz == null) {
          obj = {
            name: ydatas[i].name,
            symbol: 'circle', // 折点形状
            symbolSize: 10, // 大小
            smooth: false, // 直线 ，true 为曲线
            yAxisIndex: 1,
            itemStyle: {
              normal: {
                color: function (c) { // 根据value 显示不同的折点颜色
                  let biaozhuiz
                  for (let i = 0; i < bzzList.length; i++) {
                    if (bzzList[i].name === c.seriesName) {
                      biaozhuiz = bzzList[i].bzhui
                    }
                  }
                  if (c.value[1] > biaozhuiz) {
                    return zdcbcolor
                  } else if (c.value[1] > biaozhuiz * 0.9) {
                    return '#FFA500'
                  } else {
                    return '#33c95f'
                  }
                },
                lineStyle: { // 折线的颜色
                  color: ydatas[i].zxcolor,
                  width: 5
                },
                borderColor: ydatas[i].zxcolor, // 折点边框的颜色
                label: { // 显示值
                  show: false
                }
              }
            },
            type: 'line',
            data: ydatas[i].data
          }
        } else {
          obj = {
            name: ydatas[i].name,
            symbol: 'circle', // 折点形状
            symbolSize: 10, // 大小
            smooth: false, // 直线 ，true 为曲线
            itemStyle: {
              normal: {
                color: function (c) { // 根据value 显示不同的折点颜色
                  let biaozhuiz
                  for (let i = 0; i < bzzList.length; i++) {
                    if (bzzList[i].name === c.seriesName) {
                      biaozhuiz = bzzList[i].bzhui
                    }
                  }
                  if (c.value[1] > biaozhuiz) {
                    return zdcbcolor
                  } else if (c.value[1] > biaozhuiz * 0.9) {
                    return '#FFA500'
                  } else {
                    return '#33c95f'
                  }
                },
                lineStyle: { // 折线的颜色
                  color: ydatas[i].zxcolor,
                  width: 5
                },
                borderColor: ydatas[i].zxcolor, // 折点边框的颜色
                label: { // 显示值
                  show: false
                }
              }
            },
            type: 'line',
            data: ydatas[i].data,
            markLine: { // 平均值 ， 和 指标上限
              symbol: 'none',
              data: [
                /* {
                     type: 'average',
                     name: '日平均值',
                     label: {
                         normal: {
                             position: 'end',  //显示位置
                             formatter:  ydatas[i].name+'\n日平均值'+'{c}' //显示样式
                         }
                     },
                     lineStyle:{   // 颜色
                         color: 'yellow',
                         type:'solid'
                     }
                 }, */ {
                  label: {
                    normal: {
                      position: 'end',
                      formatter: '' // ydatas[i].name+'标准值'//+'{c}'
                    }
                  },
                  name: '标准值',
                  yAxis: bzz,
                  lineStyle: {
                    color: ydatas[i].zxcolor,
                    type: 'dashed',
                    width: 2
                  }
                }
              ]
            }
          }
        }
        serLists.push(obj)
      }

      const option = {
        tooltip: { // 提示框
          trigger: 'axis',
          axisPointer: {
            type: 'cross',
            label: {
              color: '#1a4245'
            }
          },
          formatter: function (params) {
            let s = params[0].name + '<br/>'
            for (let i = 0; i < params.length; i++) {
              // const name = params[i].name
              // 图表title名称
              const seriesName = params[i].seriesName
              // 值
              const value = params[i].value
              let valueFliter
              if (value === 'NaN') {
                valueFliter = ''
              } else {
                // valueFliter = formatter(value)
                valueFliter = value
              }
              let maker = params[i].marker
              if (seriesName === '二氧化硫') {
                maker = '<span style="display:inline-block;margin-right:5px;border-radius:10px;width:10px;height:10px;background-color:#fff21c;"></span>'
              } else if (seriesName === '氮氧化物') {
                maker = '<span style="display:inline-block;margin-right:5px;border-radius:10px;width:10px;height:10px;background-color:#00B0F0;"></span>'
              } else if (seriesName === '烟尘') {
                maker = '<span style="display:inline-block;margin-right:5px;border-radius:10px;width:10px;height:10px;background-color:#f48183;"></span>'
              } else if (seriesName === '温度') {
                maker = '<span style="display:inline-block;margin-right:5px;border-radius:10px;width:10px;height:10px;background-color:#F206FF;"></span>'
              } else if (seriesName === '废气流量') {
                maker = '<span style="display:inline-block;margin-right:5px;border-radius:10px;width:10px;height:10px;background-color:#70ff49;"></span>'
              }
              s += maker + seriesName + ':' + valueFliter + '<br />'
            }
            return s
          }
        },
        toolbox: { // 打印等工具
          show: false,
          feature: {
            saveAsImage: {}
          }
        },
        grid: {
          // 与绝对定位相似，top，left，right，bottom 设定是根据上级盒子宽高来计算
          top: '20%',
          left: '6%',
          right: '8%',
          bottom: '12%'
        },
        legend: { // 图例
          data: legend
        },
        dataZoom: [{
          type: 'inside',
          start: 0,
          end: 100
        }, {
          start: 0,
          end: 100,
          show: false,
          handleIcon: 'M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4v1.3h1.3v-1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7V23h6.6V24.4z M13.3,19.6H6.7v-1.4h6.6V19.6z',
          handleSize: '80%',
          handleStyle: {
            color: '#fff',
            shadowBlur: 3,
            shadowColor: 'rgba(0, 0, 0, 0.6)',
            shadowOffsetX: 2,
            shadowOffsetY: 2
          }
        }],
        xAxis: { // x 轴设置
          type: 'category',
          boundaryGap: false,
          axisLabel: { // x轴全部显示
            // rotate: 20,
            // interval: 0,
            textStyle: {
              color: '#fff'
            }
          },
          splitLine: { // 网格垂直线为 虚线
            show: true,
            lineStyle: {
              type: 'dashed'
            }
          },
          axisTick: { // x 轴刻度显示
            show: false
          },
          axisLine: {
            lineStyle: {
              color: '#FFFFFF',
              width: 1// 这里是为了突出显示加上的
            }
          },
          data: xdata
        },
        yAxis: [{
          type: 'value',
          name: yname,
          // max: function (value) {
          //   let max_val_list = [] // 所有显示折线的标准值
          //   if (exhbzzList && exhbzzList.length > 0) {
          //     if (value.max != '-Infinity') { // 获取所有监测指标的max值 2020/12/31
          //       valMax = parseInt(value.max + 5)
          //     }
          //     $.each(exhbzzList, function (index, item) {
          //       if (item.bzhui != null) {
          //         max_val_list.push(item.bzhui)
          //       }
          //     })
          //   }
          //   max_val_list = max_val_list.sort(function (a, b) {
          //     return a - b
          //   }) // 排序
          //   const ma = value.max > max_val_list[max_val_list.length - 1] ? value.max + 5 : max_val_list[max_val_list.length - 1]
          //   return parseInt(ma)
          // },
          axisLabel: {
            formatter: '{value}',
            textStyle: {
              color: '#fff'
            }
          },
          axisPointer: {
            snap: true
          },
          splitLine: {
            show: false
          }, // y轴 网格线不显示,
          axisLine: {
            lineStyle: {
              color: '#FFFFFF',
              width: 1// 这里是为了突出显示加上的
            }
          }
        }, {
          type: 'value',
          name: dataUnit,
          max: function (value) {
            const ma = value.max > 12 ? value.max : 120
            return parseInt(ma)
          },
          axisLabel: {
            formatter: '{value}',
            textStyle: {
              color: '#fff'
            }
          },
          axisPointer: {
            snap: true
          },
          splitLine: {
            show: false
          }, // y轴 网格线不显示,
          axisLine: {
            lineStyle: {
              color: '#FFFFFF',
              width: 1// 这里是为了突出显示加上的
            }
          }
        }],
        series: serLists
      }
      this.myChart.setOption(option)
    },
    analysisResult (result) {
      // 处理表格头
      const json = {}
      const arr = []
      // 处理表格内容
      const bodyDataList = []
      const dataMap = {}
      for (let i = 0; i < result.length; i++) {
        json[result[i].PoltmtrlName] = result[i].PoltmtrlName
        const rgdata = result[i]
        const timeTag = rgdata.MonTimeStr
        if (!dataMap[timeTag]) {
          dataMap[timeTag] = { MonTimeStr: '' + rgdata.MonTimeStr }
        }

        // 往数据中添加属性数据
        const el = dataMap[timeTag]
        el.OnLineMonEmissPointName = rgdata.OnLineMonEmissPointName
        el[rgdata.PoltmtrlName + '_OrglQty'] = rgdata.OrglQty ? rgdata.OrglQty.toFixed(2) : '--' // 原始值
        el[rgdata.PoltmtrlName + '_ConvertQty'] = rgdata.ConvertQty ? rgdata.ConvertQty.toFixed(2) : '--' // 折标量
        el[rgdata.PoltmtrlName + '_StdValue'] = rgdata.StdValue ? rgdata.StdValue.toFixed(2) : '--' // 标准值
        el[rgdata.PoltmtrlName + '_EmissQty'] = rgdata.EmissQty ? rgdata.EmissQty.toFixed(2) : '--' // 排放量
        el[rgdata.PoltmtrlName + '_MonQty'] = rgdata.MonQty ? rgdata.MonQty.toFixed(2) : '--' // 监测量
      }
      let FQLLtemp = ''
      let FQWDtemp = ''
      let FQYHLtemp = ''
      for (var key in json) {
        if (key === '废气流量' || key === '废气') {
          FQLLtemp = key
        } else if (key === '温度') {
          FQWDtemp = key
        } else if (key === '氧含量') {
          FQYHLtemp = key
        } else {
          arr.push(key)
        }
      }
      if (FQLLtemp != null) {
        arr.push(FQLLtemp)
      }
      if (FQWDtemp != null) {
        arr.push(FQWDtemp)
      }
      if (FQYHLtemp != null) {
        arr.push(FQYHLtemp)
      }
      for (var p in dataMap) {
        bodyDataList.push(dataMap[p])
      }
      return bodyDataList
    }
  }
}
</script>

<style lang="less">
.waste-gas-day-chart-box .echarts-form .el-input__inner {
  background-color: rgba(0, 0, 0, 0);
  height: .13rem;
  border-color: #336fa4;
}
.waste-gas-day-chart-box .echarts-form{
  margin-top: 1px
}
.waste-gas-day-chart-box .echarts-form .el-input__icon{
  height: .13rem;
  top: -.02rem;
  right: -0.03rem;
  position: absolute;
  color: #00d0f9;
}
.waste-gas-day-chart-box .echarts-form .selectBox .el-input__icon:last-child{
  top: .02rem;
}
.waste-gas-day-chart-box .echarts-form .selectBox .is-reverse{
  top: -.02rem !important;
}
.waste-gas-day-chart-box .echarts-form .el-button{
  background-color: rgba(0, 0, 0, 0);
  height: .13rem;
}
.waste-gas-day-chart-box .echarts-form .mingxiBtn{
  margin-left: -.02rem;
}
</style>
